Maintainance mode
-----------------

As of pyqode 2.11, the project has entered in maintainance mode. Only critical bug fixes will be adressed. The core
team won't add any new features but we will continue to accept PR as long as they are properly tested and not too risky.

Report bugs or ask a question
-----------------------------

You can report bugs or ask question on our `centralised issue tracker`_.

Submitting pull requests:
-------------------------

Pull Requests are great!

1) Fork the Repo on github.
2) Create a feature/bug fix branch based on the dev branch
3) If you are adding functionality or fixing a bug, please add a test!
4) Add your name to AUTHORS.rst
5) Push to your fork and submit a pull request to **the master branch**.

Please use **PEP8** to style your code (PEP8 compliance is tested Travis CI)::

    python setup.py test -a "--pep8 -m pep8"

.. _centralised issue tracker: https://github.com/pyQode/pyQode/issues
